@@ -633,6 +633,8 @@ struct hostap_bss_info {
 	size_t wpa_ie_len;
 	u8 rsn_ie[MAX_WPA_IE_LEN];
 	size_t rsn_ie_len;
+	int chan;
+	int included;
 };
 
 
@@ -938,6 +940,10 @@ struct hostap_interface {
 	 * shared by all virtual interfaces. Currently, only the main data
 	 * device (wlan#) is used for iwspy entries. */
 	struct iw_spy_data spy_data; /* iwspy support */
+#if WIRELESS_EXT > 16
+	/* This is the fix for the problem described above. Jean II */
+	struct iw_public_data	wireless_data;
+#endif /* WIRELESS_EXT > 16 */
 #endif /* WIRELESS_EXT > 15 */
 
 	enum {
